pub fn it_works() {
    println!("It works! a voice comes from mylib::utils::it_works")
}

pub fn add_class(id : i32) {
    println!("We set up a new class {}.", id)
}

pub fn add_student(name: &str) {
    println!("Here comes a new student {}. ", name)
}

pub fn take_attendance() {
    println!("Class 1 have 3 student, There are Allen, Steven, Mark, ")
}
